#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IF_ELSE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IF_ELSE_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/if_else.hpp>

#endif
